@@ -1,4 +1,4 @@
-# $Id: frontend.py 6154 2009-10-05 19:08:10Z milde $
+# $Id: frontend.py 6205 2009-11-30 08:11:08Z milde $
 # Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
@@ -22,6 +22,7 @@ Also exports the following functions:
   `validate_threshold`, `validate_colon_separated_string_list`,
   `validate_dependency_file`.
 * `make_paths_absolute`.
+* SettingSpec manipulation: `filter_settings_spec`.
 """
 
 __docformat__ = 'reStructuredText'
@@ -200,6 +201,35 @@ def make_paths_absolute(pathdict, keys, base_path=None):
 def make_one_path_absolute(base_path, path):
     return os.path.abspath(os.path.join(base_path, path))
 
+def filter_settings_spec(settings_spec, *exclude, **replace):
+    """Return a copy of `settings_spec` excluding/replacing some settings.
+
+    `settings_spec` is a tuple of configuration settings with a structure
+    described for docutils.SettingsSpec.settings_spec.
+
+    Optional positional arguments are names of to-be-excluded settings.
+    Keyword arguments are option specification replacements.
+    (See the html4strict writer for an example.)
+    """
+    settings = list(settings_spec)
+    # every third item is a sequence of option tuples
+    for i in range(2, len(settings), 3):
+        newopts = []
+        for opt_spec in settings[i]:
+            # opt_spec is ("<help>", [<option strings>], {<keyword args>})
+            opt_name = [opt_string[2:].replace('-', '_')
+                        for opt_string in opt_spec[1]
+                            if opt_string.startswith('--')
+                       ][0]
+            if opt_name in exclude:
+                continue
+            if opt_name in replace.keys():
+                newopts.append(replace[opt_name])
+            else:
+                newopts.append(opt_spec)
+        settings[i] = tuple(newopts)
+    return tuple(settings)
+
 
 class Values(optparse.Values):
 
@@ -294,12 +324,7 @@ class OptionParser(optparse.OptionParser, docutils.SettingsSpec):
     except AttributeError:
         default_error_encoding = 'ascii'
 
-    # TODO: variable no longer needed since 'backslashreplace' is
-    # part of Python >= 2.3 (required since Docutils 0.6)
-    if hasattr(codecs, 'backslashreplace_errors'):
-        default_error_encoding_error_handler = 'backslashreplace'
-    else:
-        default_error_encoding_error_handler = 'replace'
+    default_error_encoding_error_handler = 'backslashreplace'
 
     settings_spec = (
         'General Docutils Options',
