@@ -1,4 +1,4 @@
-# $Id: nodes.py 6011 2009-07-09 10:00:07Z gbrandl $
+# $Id: nodes.py 6351 2010-07-03 14:19:09Z gbrandl $
 # Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
@@ -335,17 +335,14 @@ class Text(Node, reprunicode):
         self.rawsource = rawsource
         """The raw text from which this element was constructed."""
 
-    def __repr__(self):
-        data = reprunicode.__repr__(self)
-        if len(data) > 70:
-            data = reprunicode.__repr__(self[:64] + ' ...')
-        return '<%s: %s>' % (self.tagname, data)
+    def shortrepr(self, maxlen=18):
+        data = self
+        if len(data) > maxlen:
+            data = data[:maxlen-4] + ' ...'
+        return '<%s: %s>' % (self.tagname, repr(reprunicode(data)))
 
-    def shortrepr(self):
-        data = reprunicode.__repr__(self)
-        if len(data) > 20:
-            data = reprunicode.__repr__(self[:16] + ' ...')
-        return '<%s: %s>' % (self.tagname, data)
+    def __repr__(self):
+        return self.shortrepr(maxlen=68)
 
     def _dom_node(self, domroot):
         return domroot.createTextNode(unicode(self))
@@ -742,7 +739,7 @@ class Element(Node):
                         for child in self.children])
 
     def copy(self):
-        return self.__class__(**self.attributes)
+        return self.__class__(rawsource=self.rawsource, **self.attributes)
 
     def deepcopy(self):
         copy = self.copy()
@@ -1840,9 +1837,10 @@ def make_id(string):
         id = id.decode()
     id = id.translate(_non_id_translate_digraphs)
     id = id.translate(_non_id_translate)
-    # get rid of non-ascii characters
+    # get rid of non-ascii characters.
+    # 'ascii' lowercase to prevent problems with turkish locale.
     id = unicodedata.normalize('NFKD', id).\
-         encode('ASCII', 'ignore').decode('ASCII')
+         encode('ascii', 'ignore').decode('ascii')
     # shrink runs of whitespace and replace by hyphen
     id = _non_id_chars.sub('-', ' '.join(id.split()))
     id = _non_id_at_ends.sub('', id)
