@@ -1,4 +1,4 @@
-# $Id: DocutilsTestSupport.py 6159 2009-10-09 07:17:59Z milde $
+# $Id: DocutilsTestSupport.py 6320 2010-05-07 08:16:56Z milde $
 # Authors: David Goodger <goodger@python.org>;
 #          Garth Kidd <garth@deadlybloodyserious.com>
 # Copyright: This module has been placed in the public domain.
@@ -195,9 +195,9 @@ class CustomTestCase(StandardTestCase):
             # API difference: Python 3's node.__str__ doesn't escape
             #assert expected is None or isinstance(expected, unicode)
             if isinstance(expected, bytes):
-                expected = expected.decode('ascii')
+                expected = expected.decode('utf-8')
             if isinstance(output, bytes):
-                output = output.decode('ascii')
+                output = output.decode('utf-8')
         else:
             if isinstance(expected, unicode):
                 expected = expected.encode('raw_unicode_escape')
