@@ -1,7 +1,7 @@
 #!/bin/sh
 ''''exec python -u "$0" "$@" #'''
 
-# $Id: alltests.py 4629 2006-06-22 19:03:06Z goodger $
+# $Id: alltests.py 6334 2010-06-02 11:49:22Z milde $
 # Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
@@ -78,8 +78,9 @@ if __name__ == '__main__':
     print 'Working directory: %s' % os.getcwd()
     print 'Docutils package: %s' % os.path.dirname(docutils.__file__)
     sys.stdout.flush()
-    package_unittest.main(suite)
+    result = package_unittest.main(suite)
     #if package_unittest.verbosity > 1:
     #    print >>sys.stderr, pformat(suite) # check the test suite
     finish = time.time()
     print 'Elapsed time: %.3f seconds' % (finish - start)
+    sys.exit(not result.wasSuccessful())
