@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-# $Id: test_language.py 5033 2007-03-21 19:51:22Z wiemann $
+# $Id: test_language.py 5738 2008-11-30 08:59:04Z grubert $
 # Authors: Engelbert Gruber <grubert@users.sourceforge.net>;
 #          David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
@@ -15,7 +15,6 @@ that language.
 import sys
 import os
 import re
-from types import UnicodeType
 import DocutilsTestSupport              # must be imported before docutils
 import docutils.languages
 import docutils.parsers.rst.languages
@@ -76,10 +75,10 @@ class LanguageTestCase(DocutilsTestSupport.CustomTestCase):
         missing  = []   # in ref but not in l.
         too_much = []   # in l but not in ref.
         for label in ref_dict.keys():
-            if not l_dict.has_key(label):
+            if label not in l_dict:
                 missing.append(label)
         for label in l_dict.keys():
-            if not ref_dict.has_key(label):
+            if label not in ref_dict:
                 too_much.append(label)
         return (missing, too_much)
 
@@ -140,12 +139,12 @@ class LanguageTestCase(DocutilsTestSupport.CustomTestCase):
         canonical.sort()
         canonical.remove('restructuredtext-test-directive')
         for name in canonical:
-            if not inverted.has_key(name):
+            if name not in inverted:
                 failures.append('"%s": translation missing' % name)
         if failures:
             text = ('Module docutils.parsers.rst.languages.%s:\n    %s'
                     % (self.language, '\n    '.join(failures)))
-            if type(text) == UnicodeType:
+            if type(text) is unicode:
                 text = text.encode('raw_unicode_escape')
             self.fail(text)
 
@@ -175,12 +174,12 @@ class LanguageTestCase(DocutilsTestSupport.CustomTestCase):
         canonical.sort()
         canonical.remove('restructuredtext-unimplemented-role')
         for name in canonical:
-            if not inverted.has_key(name):
+            if name not in inverted:
                 failures.append('"%s": translation missing' % name)
         if failures:
             text = ('Module docutils.parsers.rst.languages.%s:\n    %s'
                     % (self.language, '\n    '.join(failures)))
-            if type(text) == UnicodeType:
+            if type(text) is unicode:
                 text = text.encode('raw_unicode_escape')
             self.fail(text)
 
