@@ -1,7 +1,7 @@
 #! /usr/bin/env python
 # -*- coding: utf-8 -*-
 
-# $Id: test_nodes.py 5889 2009-04-01 20:00:21Z gbrandl $
+# $Id: test_nodes.py 6351 2010-07-03 14:19:09Z gbrandl $
 # Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
@@ -24,9 +24,15 @@ class TextTests(unittest.TestCase):
     def setUp(self):
         self.text = nodes.Text('Line 1.\nLine 2.')
         self.unicode_text = nodes.Text(u'Möhren')
+        self.longtext = nodes.Text('Mary had a little lamb whose '
+                                   'fleece was white as snow and '
+                                   'everwhere that Mary went the '
+                                   'lamb was sure to go.')
 
     def test_repr(self):
         self.assertEquals(repr(self.text), r"<#text: 'Line 1.\nLine 2.'>")
+        self.assertEquals(self.text.shortrepr(),
+                          r"<#text: 'Line 1.\nLine 2.'>")
 
     def test_str(self):
         self.assertEquals(str(self.text), 'Line 1.\nLine 2.')
@@ -43,12 +49,18 @@ class TextTests(unittest.TestCase):
 
     def test_asciirestriction(self):
         if sys.version_info < (3,):
-            self.assertRaises(UnicodeError, nodes.Text, b('hol%s' % chr(224)))
-            # more specifically: UnicodeDecodeError since py2.3
+            self.assertRaises(UnicodeDecodeError, nodes.Text,
+                              b('hol%s' % chr(224)))
         else:
             # no bytes at all allowed
             self.assertRaises(TypeError, nodes.Text, b('hol'))
 
+    def test_longrepr(self):
+        self.assertEquals(repr(self.longtext), r"<#text: 'Mary had a "
+                          r"little lamb whose fleece was white as snow "
+                          r"and everwh ...'>")
+        self.assertEquals(self.longtext.shortrepr(),
+                          r"<#text: 'Mary had a lit ...'>")
 
 class ElementTests(unittest.TestCase):
 
@@ -445,15 +457,15 @@ class MiscTests(unittest.TestCase):
         # Shallow copy:
         e_copy = e.copy()
         self.assert_(e is not e_copy)
-        # Internal attributes (like `rawsource`) are not copied.
+        # Internal attributes (like `rawsource`) are also copied.
         self.assertEquals(e.rawsource, 'rawsource')
-        self.assertEquals(e_copy.rawsource, '')
+        self.assertEquals(e_copy.rawsource, e.rawsource)
         self.assertEquals(e_copy['att'], 'e')
         # Children are not copied.
         self.assertEquals(len(e_copy), 0)
         # Deep copy:
         e_deepcopy = e.deepcopy()
-        self.assertEquals(e_deepcopy.rawsource, '')
+        self.assertEquals(e_deepcopy.rawsource, e.rawsource)
         self.assertEquals(e_deepcopy['att'], 'e')
         # Children are copied recursively.
         self.assertEquals(e_deepcopy[0][0], grandchild)
