@@ -1,9 +1,7 @@
 #! /usr/bin/env python
 
-# Author: David Goodger
-# Contact: goodger@python.org
-# Revision: $Revision: 4229 $
-# Date: $Date: 2005-12-23 00:46:16 +0100 (Fri, 23 Dec 2005) $
+# $Id: test_date.py 4667 2006-07-12 21:40:56Z wiemann $
+# Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
 """
@@ -45,6 +43,17 @@ Today's date is |date|.
     <substitution_definition names="date">
         %s
 """ % time.strftime('%a, %d %b %Y')],
+["""\
+.. date::
+""",
+"""\
+<document source="test data">
+    <system_message level="3" line="1" source="test data" type="ERROR">
+        <paragraph>
+            Invalid context: the "date" directive can only be used within a substitution definition.
+        <literal_block xml:space="preserve">
+            .. date::
+"""],
 ]
 
 
