@@ -1,6 +1,6 @@
 #! /usr/bin/env python
 
-# $Id: test_figures.py 4564 2006-05-21 20:44:42Z wiemann $
+# $Id: test_figures.py 5952 2009-05-19 08:45:27Z milde $
 # Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
@@ -98,7 +98,7 @@ totest['figures'] = [
 """,
 """\
 <document source="test data">
-    <figure classes="class1 class2" width="300">
+    <figure classes="class1 class2" width="300px">
         <image alt="alternate text" height="100" scale="50" uri="picture.png" width="200">
         <caption>
             A picture with image options on individual lines, and this caption.
