@@ -1,6 +1,6 @@
 #! /usr/bin/env python
 
-# $Id: test_include.py 6135 2009-09-21 21:28:48Z milde $
+# $Id: test_include.py 6314 2010-04-26 10:04:17Z milde $
 # Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
@@ -35,6 +35,12 @@ include13rel = DocutilsTestSupport.utils.relative_path(None, include13)
 include_literal = os.path.join(mydir, 'include_literal.txt')
 utf_16_file = os.path.join(mydir, 'utf-16.csv')
 utf_16_file_rel = DocutilsTestSupport.utils.relative_path(None, utf_16_file)
+utf_16_error_str = ("UnicodeDecodeError: 'ascii' codec can't decode byte 0xfe "
+                    "in position 0: ordinal not in range(128)")
+if sys.version_info < (3,0):
+    utf_16_error_str = ("UnicodeError: Unable to decode input data.  "
+                        "Tried the following encodings: 'ascii'.\n"
+                        "            (%s)" % utf_16_error_str)
 nonexistent = os.path.join(os.path.dirname(states.__file__),
                            'include', 'nonexistent')
 nonexistent_rel = DocutilsTestSupport.utils.relative_path(
@@ -317,34 +323,246 @@ Include file is UTF-16-encoded, and is not valid ASCII.
     <system_message level="4" line="3" source="test data" type="SEVERE">
         <paragraph>
             Problem with "include" directive:
-            UnicodeError: Unable to decode input data.  Tried the following encodings: 'ascii'.
-            (UnicodeDecodeError: 'ascii' codec can't decode byte 0xfe in position 0: ordinal not in range(128))
+            %s
         <literal_block xml:space="preserve">
             .. include:: %s
                :encoding: ascii
-""" % utf_16_file_rel],
+""" % (utf_16_error_str, utf_16_file_rel)],
 # @@@ BUG with errors reported with incorrect "source" & "line":
-# ["""\
-# Testing bad charent includes:
-#
-# .. include:: %s
-# """ % include10,
-# """\
-# <document source="test data">
-#     <paragraph>
-#         Testing bad charent includes:
-#     <system_message level="3" line="1" source="%s" type="ERROR">
-#         <paragraph>
-#             Invalid character code: 0xFFFFFFFFF
-#             int() literal too large: FFFFFFFFF
-#         <literal_block xml:space="preserve">
-#             unicode:: 0xFFFFFFFFF
-#     <system_message level="2" line="1" source="%s" type="WARNING">
-#         <paragraph>
-#             Substitution definition "bad" empty or invalid.
-#         <literal_block xml:space="preserve">
-#             .. |bad| unicode:: 0xFFFFFFFFF
-# """ % (include10rel, include10rel)],
+["""\
+Testing errors in included file:
+
+.. include:: %s
+""" % include10,
+"""\
+<document source="test data">
+    <paragraph>
+        Testing errors in included file:
+    <system_message level="3" line="1" source="%(source)s" type="ERROR">
+        <paragraph>
+            Invalid character code: 0x11111111
+            %(unichr_exception)s
+        <literal_block xml:space="preserve">
+            unicode:: 0x11111111
+    <system_message level="2" line="1" source="%(source)s" type="WARNING">
+        <paragraph>
+            Substitution definition "bad" empty or invalid.
+        <literal_block xml:space="preserve">
+            .. |bad| unicode:: 0x11111111
+    <section dupnames="hi" ids="hi">
+        <title>
+            hi
+        <block_quote>
+            <paragraph>
+                indent
+        <system_message level="2" line="7" source="%(source)s" type="WARNING">
+            <paragraph>
+                Block quote ends without a blank line; unexpected unindent.
+        <paragraph>
+            error
+    <section dupnames="hi" ids="id1">
+        <title>
+            hi
+        <system_message backrefs="id1" level="1" line="10" source="%(source)s" type="INFO">
+            <paragraph>
+                Duplicate implicit target name: "hi".
+        <system_message level="4" line="12" source="%(source)s" type="SEVERE">
+            <paragraph>
+                Problems with "include" directive path:
+                IOError: [Errno 2] No such file or directory: '%(nonexistent)s'.
+            <literal_block xml:space="preserve">
+                .. include:: <nonexistent>
+        <system_message level="3" line="14" source="%(source)s" type="ERROR">
+            <paragraph>
+                Content block expected for the "note" directive; none found.
+            <literal_block xml:space="preserve">
+                .. note::
+        <system_message level="3" line="16" source="%(source)s" type="ERROR">
+            <paragraph>
+                Content block expected for the "admonition" directive; none found.
+            <literal_block xml:space="preserve">
+                .. admonition::
+                   without title
+        <system_message level="3" line="19" source="%(source)s" type="ERROR">
+            <paragraph>
+                Content block expected for the "epigraph" directive; none found.
+            <literal_block xml:space="preserve">
+                .. epigraph::
+        <system_message level="3" line="21" source="%(source)s" type="ERROR">
+            <paragraph>
+                Content block expected for the "highlights" directive; none found.
+            <literal_block xml:space="preserve">
+                .. highlights::
+        <system_message level="3" line="23" source="%(source)s" type="ERROR">
+            <paragraph>
+                Content block expected for the "pull-quote" directive; none found.
+            <literal_block xml:space="preserve">
+                .. pull-quote::
+        <system_message level="3" line="25" source="%(source)s" type="ERROR">
+            <paragraph>
+                Invalid context: the "date" directive can only be used within a substitution definition.
+            <literal_block xml:space="preserve">
+                .. date::
+        <paragraph>
+            not a
+            definition list:
+        <system_message level="3" line="29" source="%(source)s" type="ERROR">
+            <paragraph>
+                Unexpected indentation.
+        <block_quote>
+            <paragraph>
+                as a term may only be one line long.
+        <system_message level="3" line="31" source="%(source)s" type="ERROR">
+            <paragraph>
+                Error in "admonition" directive:
+                1 argument(s) required, 0 supplied.
+            <literal_block xml:space="preserve">
+                .. admonition::
+                
+                   without title and content following a blank line
+    <section ids="section-underline-too-short" names="section\ underline\ too\ short">
+        <title>
+            section underline too short
+        <system_message level="2" line="36" source="%(source)s" type="WARNING">
+            <paragraph>
+                Title underline too short.
+            <literal_block xml:space="preserve">
+                section underline too short
+                -----
+        <table>
+            <tgroup cols="2">
+                <colspec colwidth="14">
+                <colspec colwidth="6">
+                <thead>
+                    <row>
+                        <entry>
+                            <paragraph>
+                                A simple table
+                        <entry>
+                            <paragraph>
+                                cell 2
+                <tbody>
+                    <row>
+                        <entry>
+                            <paragraph>
+                                cell 3
+                        <entry>
+                            <paragraph>
+                                cell 4
+        <system_message level="2" line="43" source="%(source)s" type="WARNING">
+            <paragraph>
+                Blank line required after table.
+        <paragraph>
+            No blank line after table.
+        <system_message level="3" line="45" source="%(source)s" type="ERROR">
+            <paragraph>
+                Error in "unicode" directive:
+                1 argument(s) required, 0 supplied.
+            <literal_block xml:space="preserve">
+                unicode::
+        <system_message level="2" line="45" source="%(source)s" type="WARNING">
+            <paragraph>
+                Substitution definition "empty" empty or invalid.
+            <literal_block xml:space="preserve">
+                .. |empty| unicode::
+        <system_message level="3" line="47" source="%(source)s" type="ERROR">
+            <paragraph>
+                Error in "topic" directive:
+                1 argument(s) required, 0 supplied.
+            <literal_block xml:space="preserve">
+                .. topic::
+        <system_message level="3" line="49" source="%(source)s" type="ERROR">
+            <paragraph>
+                Error in "rubric" directive:
+                1 argument(s) required, 0 supplied.
+            <literal_block xml:space="preserve">
+                .. rubric::
+        <rubric>
+            A rubric has no content
+        <comment xml:space="preserve">
+            _`target: No matching backquote.
+        <system_message level="2" line="52" source="%(source)s" type="WARNING">
+            <paragraph>
+                malformed hyperlink target.
+        <comment xml:space="preserve">
+            __malformed: no good
+        <system_message level="2" line="53" source="%(source)s" type="WARNING">
+            <paragraph>
+                malformed hyperlink target.
+        <definition_list>
+            <definition_list_item>
+                <term>
+                    A literal block::
+                <definition>
+                    <system_message level="1" line="57" source="%(source)s" type="INFO">
+                        <paragraph>
+                            Blank line missing before literal block (after the "::")? Interpreted as a definition list item.
+                    <paragraph>
+                        with no blank line above.
+        <literal_block xml:space="preserve">
+            > A literal block.
+        <system_message level="3" line="61" source="%(source)s" type="ERROR">
+            <paragraph>
+                Inconsistent literal block quoting.
+        <paragraph>
+            $ with inconsistent quoting.
+        <paragraph>
+            <problematic ids="id3" refid="id2">
+                :unknown-role:`role`
+            
+            and 
+            <problematic ids="id5" refid="id4">
+                *
+            unbalanced
+            <problematic ids="id7" refid="id6">
+                `
+            inline
+            <problematic ids="id9" refid="id8">
+                **
+            markup
+        <system_message level="1" line="63" source="%(source)s" type="INFO">
+            <paragraph>
+                No role entry for "unknown-role" in module "docutils.parsers.rst.languages.en".
+                Trying "unknown-role" as canonical role name.
+        <system_message backrefs="id3" ids="id2" level="3" line="63" source="%(source)s" type="ERROR">
+            <paragraph>
+                Unknown interpreted text role "unknown-role".
+        <system_message backrefs="id5" ids="id4" level="2" line="63" source="%(source)s" type="WARNING">
+            <paragraph>
+                Inline emphasis start-string without end-string.
+        <system_message backrefs="id7" ids="id6" level="2" line="63" source="%(source)s" type="WARNING">
+            <paragraph>
+                Inline interpreted text or phrase reference start-string without end-string.
+        <system_message backrefs="id9" ids="id8" level="2" line="63" source="%(source)s" type="WARNING">
+            <paragraph>
+                Inline strong start-string without end-string.
+        <paragraph>
+            <problematic ids="id11" refid="id10">
+                :PEP:`-1`
+        <system_message backrefs="id11" ids="id10" level="3" line="68" source="%(source)s" type="ERROR">
+            <paragraph>
+                PEP number must be a number from 0 to 9999; "-1" is invalid.
+        <system_message level="1" line="66" source="%(source)s" type="INFO">
+            <paragraph>
+                No directive entry for "unknown" in module "docutils.parsers.rst.languages.en".
+                Trying "unknown" as canonical directive name.
+        <system_message level="3" line="70" source="%(source)s" type="ERROR">
+            <paragraph>
+                Unknown directive type "unknown".
+            <literal_block xml:space="preserve">
+                .. unknown:: directive (info still reported with wrong line)
+        <system_message level="3" line="72" source="%(source)s" type="ERROR">
+            <paragraph>
+                Malformed table.
+                No bottom table border found.
+            <literal_block xml:space="preserve">
+                ==============  ======
+                A simple table  with
+                no bottom       border
+""" % {'source': include10rel, 'nonexistent': nonexistent_rel,
+       'unichr_exception':
+       DocutilsTestSupport.exception_data(unichr, int("11111111", 16))[2]
+      }],
 ["""\
 Include file with whitespace in the path:
 
@@ -537,6 +755,10 @@ TAB expansion with literal include:
     <literal_block source="%s" xml:space="preserve">
         Literal included this should **not** be *marked* `up`.
                 <- leading raw tab.
+        
+        Newlines
+        are
+        normalized.
 """ % include_literal],
 ["""\
 Custom TAB expansion with literal include:
@@ -552,6 +774,10 @@ Custom TAB expansion with literal include:
     <literal_block source="%s" xml:space="preserve">
         Literal included this should **not** be *marked* `up`.
           <- leading raw tab.
+        
+        Newlines
+        are
+        normalized.
 """ % include_literal],
 ["""\
 No TAB expansion with literal include:
@@ -567,6 +793,10 @@ No TAB expansion with literal include:
     <literal_block source="%s" xml:space="preserve">
         Literal included this should **not** be *marked* `up`.
         \t<- leading raw tab.
+        
+        Newlines
+        are
+        normalized.
 """ % include_literal],
 ]
 
